@@ -1,7 +1,7 @@
 package Terse::Plugin::Config;
 
 use base 'Terse::Plugin';
-
+use JSON;
 use Data::LNPath qw/lnpath/;
 
 sub build_plugin {
@@ -10,13 +10,13 @@ sub build_plugin {
 		my $file = $0;
 		($self->config_file = $0) =~ s/(\.psgi)?$/.json/;
 	}
-	$self->data = $self->_read_file($self->config_file);
+	$self->{data} = $self->_read_file($self->config_file);
 	return $self;
 }
 
 sub find {
 	my ($self, $path) = @_;
-	return lnpath($self->config, $path);
+	return lnpath($self->{data}, $path);
 }
 
 sub _read_file {
@@ -29,7 +29,7 @@ sub _read_file {
 
 sub _parse_config {
 	my ($self, $content) = @_;
-	$self->graft('data', $content);
+	return JSON->new->decode($content);
 }
 
 1;
@@ -42,7 +42,7 @@ Terse::Plugin::Config - JSON configs
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
